@@ -10,7 +10,11 @@ sub match {
     my $regex = qr{(?:
          invalid/inactive[ ]user
         # http://service.mail.qq.com/cgi-bin/help?subtype=1&&id=20022&&no=1000742
-        |mailbox[ ]unavailable[ ]or[ ]access[ ]denied
+        |is[ ]a[ ]deactivated[ ]mailbox
+        |mailbox[ ](?:
+             currently[ ]suspended
+            |unavailable[ ]or[ ]access[ ]denied
+            )
         |user[ ]suspended   # http://mail.163.com/help/help_spam_16.htm
         |recipient[ ]suspend[ ]the[ ]service
         |sorry[ ]your[ ]message[ ]to[ ].+[ ]cannot[ ]be[ ]delivered[.][ ]this[ ]
