@@ -10,25 +10,37 @@ sub match {
     my $regex = qr{(?>
          .+[ ]user[ ]unknown
         |[#]5[.]1[.]1[ ]bad[ ]address
+        |[<].+[>][ ]not[ ]found
+        |address[ ]does[ ]not[ ]exist
         |archived[ ]recipient
         |destination[ ]server[ ]rejected[ ]recipients
         |email[ ]address[ ]does[ ]not[ ]exist
-        |invalid[ ]mailbox[ ]path
-        |invalid[ ]recipient                 # Linkedin
-        |no[ ]account[ ]by[ ]that[ ]name[ ]here
-        |no[ ]such[ ](?:
-             mailbox
-            |person[ ]at[ ]this[ ]address
-            |recipient
-            |user(?:[ ]here)?
+        |invalid[ ](?:
+             mailbox[ ]path
+            |recipient                 # Linkedin
+            )
+        |is[ ]not[ ](?:
+             a[ ]known[ ]user
+            |an[ ]active[ ]address[ ]at[ ]this[ ]host
             )
-        |[<].+[>][ ]not[ ]found
         |mailbox[ ](?:
              not[ ]present
             |not[ ]found
             |unavailable
             )
-        |no[ ].+[ ]in[ ]name[ ]directory
+        |no[ ](?:
+             account[ ]by[ ]that[ ]name[ ]here
+            |mail[ ]box[ ]available[ ]for[ ]this[ ]user
+            |mailbox[ ]found
+            |such[ ](?:
+                 mailbox
+                |person[ ]at[ ]this[ ]address
+                |recipient
+                |user(?:[ ]here)?
+                )
+            |[ ].+[ ]in[ ]name[ ]directory
+            )
+        |rcpt[ ][<].+[>][ ]does[ ]not[ ]exist
         |recipient[ ](?:
              .+[ ]was[ ]not[ ]found[ ]in
             |address[ ]rejected:[ ](?:
@@ -38,13 +50,15 @@ sub match {
                 |user[ ]unknown[ ]in[ ].+[ ]table
                 |unknown[ ]user
                 )
+            |does[ ]not[ ]exist(?:[ ]on[ ]this[ ]system)?
             |is[ ]not[ ]local
             |not[ ]found
             )
-        |Requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
+        |requested[ ]action[ ]not[ ]taken:[ ]mailbox[ ]unavailable
         |said:[ ]550[-[ ]]5[.]1[.]1[ ].+[ ]user[ ]unknown[ ]
         |sorry,[ ](?:
              user[ ]unknown
+            |badrcptto
             |no[ ]mailbox[ ]here[ ]by[ ]that[ ]name
             )
         |this[ ]address[ ]no[ ]longer[ ]accepts[ ]mail
@@ -58,6 +72,7 @@ sub match {
             )
         |user[ ](?:
              .+[ ]was[ ]not[ ]found
+            |.+[ ]does[ ]not[ ]exist
             |missing[ ]home[ ]directory
             |not[ ]found     # 550 User not found. See http://mail.bigmir.net/err/2/
             |unknown
